# Processing Module

The `wandas.processing` module provides various processing capabilities for audio data.

## Base Processing

Provides basic processing operations.

::: wandas.processing.base

## Effects

Provides audio effect processing.

::: wandas.processing.effects

## Filters

Provides various audio filter processing.

::: wandas.processing.filters

## Spectral Processing

Provides spectral analysis and processing capabilities.

::: wandas.processing.spectral

## Statistical Processing

Provides statistical analysis functions for audio data.

::: wandas.processing.stats

## Temporal Processing

Provides time-domain processing capabilities.

::: wandas.processing.temporal
